==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1ScopedResourceSelectorRequirementFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public class V1ScopedResourceSelectorRequirementFluentImpl<A extends V1ScopedResourceSelectorRequirementFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ScopedResourceSelectorRequirementFluent<A>{

    private String operator;
    private String scopeName;
    private List<String> values;

    public V1ScopedResourceSelectorRequirementFluentImpl(){
    }
    public V1ScopedResourceSelectorRequirementFluentImpl(V1ScopedResourceSelectorRequirement instance){
            this.withOperator(instance.getOperator());

            this.withScopeName(instance.getScopeName());

            this.withValues(instance.getValues());

    }

    public String getOperator(){
            return this.operator;
    }

    public A withOperator(String operator){
            this.operator=operator; return (A) this;
    }

    public Boolean hasOperator(){
            return this.operator != null;
    }

    public String getScopeName(){
            return this.scopeName;
    }

    public A withScopeName(String scopeName){
            this.scopeName=scopeName; return (A) this;
    }

    public Boolean hasScopeName(){
            return this.scopeName != null;
    }

    public A addToValues(int index,String item){
            if (this.values == null) {this.values = new ArrayList<String>();}
            this.values.add(index, item);
            return (A)this;
    }

    public A setToValues(int index,String item){
            if (this.values == null) {this.values = new ArrayList<String>();}
            this.values.set(index, item); return (A)this;
    }

    public A addToValues(String... items){
            if (this.values == null) {this.values = new ArrayList<String>();}
            for (String item : items) {this.values.add(item);} return (A)this;
    }

    public A addAllToValues(Collection<String> items){
            if (this.values == null) {this.values = new ArrayList<String>();}
            for (String item : items) {this.values.add(item);} return (A)this;
    }

    public A removeFromValues(String... items){
            for (String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
    }

    public A removeAllFromValues(Collection<String> items){
            for (String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
    }

    public List<String> getValues(){
            return this.values;
    }

    public String getValue(int index){
            return this.values.get(index);
    }

    public String getFirstValue(){
            return this.values.get(0);
    }

    public String getLastValue(){
            return this.values.get(values.size() - 1);
    }

    public String getMatchingValue(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: values) { if(predicate.apply(item)){return item;} } return null;
    }

    public A withValues(List<String> values){
            if (this.values != null) { _visitables.removeAll(this.values);}
            if (values != null) {this.values = new ArrayList<String>(); for (String item : values){this.addToValues(item);}} else { this.values = null;} return (A) this;
    }

    public A withValues(String... values){
            if (this.values != null) {this.values.clear();}
            if (values != null) {for (String item :values){ this.addToValues(item);}} return (A) this;
    }

    public Boolean hasValues(){
            return values != null && !values.isEmpty();
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ScopedResourceSelectorRequirementFluentImpl that = (V1ScopedResourceSelectorRequirementFluentImpl) o;
            if (operator != null ? !operator.equals(that.operator) :that.operator != null) return false;
            if (scopeName != null ? !scopeName.equals(that.scopeName) :that.scopeName != null) return false;
            if (values != null ? !values.equals(that.values) :that.values != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ScopedResourceSelectorRequirementFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1ScopedResourceSelectorRequirementFluentImpl<A extends V1ScopedResourceSelectorRequirementFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ScopedResourceSelectorRequirementFluent<A>{

    private String operator;
    private String scopeName;
    private List<String> values;

    public V1ScopedResourceSelectorRequirementFluentImpl(){
    }
    public V1ScopedResourceSelectorRequirementFluentImpl(V1ScopedResourceSelectorRequirement instance){
            this.withOperator(instance.getOperator());

            this.withScopeName(instance.getScopeName());

            this.withValues(instance.getValues());

    }

    public String getOperator(){
            return this.operator;
    }

    public A withOperator(String operator){
            this.operator=operator; return (A) this;
    }

    public Boolean hasOperator(){
            return this.operator != null;
    }

    public A withNewOperator(String arg1){
            return (A)withOperator(new String(arg1));
    }

    public A withNewOperator(StringBuilder arg1){
            return (A)withOperator(new String(arg1));
    }

    public A withNewOperator(StringBuffer arg1){
            return (A)withOperator(new String(arg1));
    }

    public String getScopeName(){
            return this.scopeName;
    }

    public A withScopeName(String scopeName){
            this.scopeName=scopeName; return (A) this;
    }

    public Boolean hasScopeName(){
            return this.scopeName != null;
    }

    public A withNewScopeName(String arg1){
            return (A)withScopeName(new String(arg1));
    }

    public A withNewScopeName(StringBuilder arg1){
            return (A)withScopeName(new String(arg1));
    }

    public A withNewScopeName(StringBuffer arg1){
            return (A)withScopeName(new String(arg1));
    }

    public A addToValues(int index,String item){
            if (this.values == null) {this.values = new ArrayList<String>();}
            this.values.add(index, item);
            return (A)this;
    }

    public A setToValues(int index,String item){
            if (this.values == null) {this.values = new ArrayList<String>();}
            this.values.set(index, item); return (A)this;
    }

    public A addToValues(String... items){
            if (this.values == null) {this.values = new ArrayList<String>();}
            for (String item : items) {this.values.add(item);} return (A)this;
    }

    public A addAllToValues(Collection<String> items){
            if (this.values == null) {this.values = new ArrayList<String>();}
            for (String item : items) {this.values.add(item);} return (A)this;
    }

    public A removeFromValues(String... items){
            for (String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
    }

    public A removeAllFromValues(Collection<String> items){
            for (String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
    }

    public List<String> getValues(){
            return this.values;
    }

    public String getValue(int index){
            return this.values.get(index);
    }

    public String getFirstValue(){
            return this.values.get(0);
    }

    public String getLastValue(){
            return this.values.get(values.size() - 1);
    }

    public String getMatchingValue(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: values) { if(predicate.apply(item)){return item;} } return null;
    }

    public Boolean hasMatchingValue(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: values) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withValues(List<String> values){
            if (this.values != null) { _visitables.get("values").removeAll(this.values);}
            if (values != null) {this.values = new ArrayList<String>(); for (String item : values){this.addToValues(item);}} else { this.values = null;} return (A) this;
    }

    public A withValues(String... values){
            if (this.values != null) {this.values.clear();}
            if (values != null) {for (String item :values){ this.addToValues(item);}} return (A) this;
    }

    public Boolean hasValues(){
            return values != null && !values.isEmpty();
    }

    public A addNewValue(String arg1){
            return (A)addToValues(new String(arg1));
    }

    public A addNewValue(StringBuilder arg1){
            return (A)addToValues(new String(arg1));
    }

    public A addNewValue(StringBuffer arg1){
            return (A)addToValues(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ScopedResourceSelectorRequirementFluentImpl that = (V1ScopedResourceSelectorRequirementFluentImpl) o;
            if (operator != null ? !operator.equals(that.operator) :that.operator != null) return false;
            if (scopeName != null ? !scopeName.equals(that.scopeName) :that.scopeName != null) return false;
            if (values != null ? !values.equals(that.values) :that.values != null) return false;
            return true;
    }




}
